@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Tiny;
 # ABSTRACT: File path utility
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 # Dependencies
 use autodie::exception 2.14; # autodie::skip support
@@ -288,9 +288,11 @@ sub iterator {
                 opendir( $dh, $current->[PATH] )
                     or _throw( 'opendir', [$dh, $current->[PATH]] );
                 $dirs[0] = $dh;
-                if ( -l $dirs[0] && ! $args->{follow_symlinks} ) {
+                if ( -l $current->[PATH] && ! $args->{follow_symlinks} ) {
                     # Symlink attack! It was a real dir, but is now a symlink!
-                    # N.B. we check *after* opendir so we don't have a race
+                    # N.B. we check *after* opendir so the attacker has to win
+                    # two races: replace dir with symlink before opendir and
+                    # replace symlink with dir before -l check above
                     shift @dirs and next;
                 }
             }
@@ -604,7 +606,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
